@@ -132,7 +132,8 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QStringLiteral("Language"),
       QStringLiteral("Certification"),
       QStringLiteral("Country"),
-      QStringLiteral("plot\\s+(outline|summary)(?!/)")
+      QStringLiteral("plot\\s+(outline|summary)(?!/)"),
+      QStringLiteral("Music by")
     }, {
       i18n("Internet Movie Database (French)"),
       QStringLiteral("www.imdb.fr"),
@@ -160,7 +161,8 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QStringLiteral("Langue"),
       QStringLiteral("Classification"),
       QStringLiteral("Pays"),
-      QStringLiteral("Intrigue\\s*")
+      QStringLiteral("Intrigue\\s*"),
+      QString() // reference page doesn't seem to have localized composer
     }, {
       i18n("Internet Movie Database (Spanish)"),
       QStringLiteral("www.imdb.es"),
@@ -188,7 +190,8 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QStringLiteral("Idioma"),
       QStringLiteral("Clasificación"),
       QStringLiteral("País"),
-      QStringLiteral("Trama\\s*")
+      QStringLiteral("Trama\\s*"),
+      QString() // reference page doesn't seem to have localized composer
     }, {
       i18n("Internet Movie Database (German)"),
       QStringLiteral("www.imdb.de"),
@@ -216,7 +219,8 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QStringLiteral("Sprache"),
       QStringLiteral("Altersfreigabe"),
       QStringLiteral("Land"),
-      QStringLiteral("Handlung\\s*")
+      QStringLiteral("Handlung\\s*"),
+      QString() // reference page doesn't seem to have localized composer
     }, {
       i18n("Internet Movie Database (Italian)"),
       QStringLiteral("www.imdb.it"),
@@ -244,7 +248,8 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QStringLiteral("Lingua"),
       QStringLiteral("Divieti"),
       QStringLiteral("Nazionalità"),
-      QStringLiteral("Trama\\s*")
+      QStringLiteral("Trama\\s*"),
+      QString() // reference page doesn't seem to have localized composer
     }, {
       i18n("Internet Movie Database (Portuguese)"),
       QStringLiteral("www.imdb.pt"),
@@ -272,7 +277,8 @@ const IMDBFetcher::LangData& IMDBFetcher::langData(int lang_) {
       QStringLiteral("Lingua"),
       QStringLiteral("Certificação"),
       QStringLiteral("País"),
-      QStringLiteral("Argumento\\s*")
+      QStringLiteral("Argumento\\s*"),
+      QString() // reference page doesn't seem to have localized composer
     }
   };
 
@@ -398,6 +404,7 @@ void IMDBFetcher::continueSearch() {
     m_currentTitleBlock = m_countOffset == 0 ? Unknown : Approx;
   }
 
+  m_hasMoreResults = false;
   stop();
 }
 
@@ -551,6 +558,15 @@ void IMDBFetcher::parseMultipleTitleResults() {
     m_currentTitleBlock = m_countOffset == 0 ? Unknown : Approx;
   }
 
+  // last resort
+  if(m_matches.size() < m_limit) {
+    const int pos_header = output.indexOf(QStringLiteral("ipc-page-content-container"));
+    const int end_header = output.indexOf(QStringLiteral("cornerstone"), qMax(0, pos_header));
+    if(pos_header > -1) {
+      parseTitleBlock(output.mid(pos_header, end_header == -1 ? output.length() : end_header));
+    }
+  }
+
   if(m_matches.size() == 0) {
     myLog() << "no matches found.";
   }
@@ -586,6 +602,8 @@ void IMDBFetcher::parseTitleBlock(const QString& str_) {
     } else {
       // parenthesis might be outside anchor tag
       int end = s_anchorTitleRx->indexIn(str_, start);
+      const int end2 = str_.indexOf(QStringLiteral("<img"), start);
+      if(end2 > -1) end = qMin(end, end2);
       if(end == -1) {
         end = str_.length();
       }
@@ -606,6 +624,12 @@ void IMDBFetcher::parseTitleBlock(const QString& str_) {
           }
         }
         pPos = -1;
+      } else {
+        static const QRegularExpression digitsRs(QStringLiteral(">([-–\\d]+)<"));
+        QRegularExpressionMatch digitsMatch = digitsRs.match(text);
+        if(digitsMatch.hasMatch()) {
+          desc = digitsMatch.captured(1);
+        }
       }
     }
     // multiple matches might have 'aka' info
@@ -722,6 +746,7 @@ Tellico::Data::EntryPtr IMDBFetcher::parseEntry(const QString& str_) {
   doStudio(str_, entry);
   doPerson(str_, entry, langData(m_lang).director, QStringLiteral("director"));
   doPerson(str_, entry, langData(m_lang).writer, QStringLiteral("writer"));
+  doPerson(str_, entry, langData(m_lang).composer, QStringLiteral("composer"));
   doRating(str_, entry);
   doCast(str_, entry, m_url);
   if(m_fetchImages) {
